-- indoorSound17.lua
-- Author RivalBomb
--
-- 06/09/15
--
-- MODDESC.XML
--
--	<specialization name="indoorSound17" className="indoorSound17" filename="scripts/indoorSound17.lua" />
--
-- VEHICLE.XML
--[[
	<motorStartSoundInside file="Sounds/start_intern.wav" pitchOffset="1" volume="0.35" radius="1" innerRadius="1" />
	<motorStopSoundInside file="Sounds/stop_intern.wav" pitchOffset="1" volume="0.35" radius="1" innerRadius="1" />
	<motorSoundRunInside file="Sounds/run_intern.wav" pitchOffset="1" volume="0.2" pitchScale="1" pitchMax="1.5" radius="1" innerRadius="1" />
	<motorSoundInside file="Sounds/idle_intern.wav" pitchOffset="1" volume="0.35" radius="1" innerRadius="1" />
]]--

indoorSound17 = {};

function indoorSound17.prerequisitesPresent(specializations)
    return SpecializationUtil.hasSpecialization(Motorized, specializations); -- and SpecializationUtil.hasSpecialization(TurnOnVehicle, specializations)
end;

function indoorSound17:load(savegame)
	self.swapSounds = SpecializationUtil.callSpecializationsFunction("swapSounds");

	self.soundSwitched = false;
	self.volume = 1;
	
	self.motorStartSoundOutside = SoundUtil.loadSample(self.xmlFile, {}, "vehicle.motorStartSound", nil, self.baseDirectory, self.components[1].node);
	self.motorIdleSoundOutside = SoundUtil.loadSample(self.xmlFile, {}, "vehicle.motorSound", nil, self.baseDirectory, self.components[1].node);
	self.motorSoundRunOutside = SoundUtil.loadSample(self.xmlFile, {}, "vehicle.motorSoundRun", nil, self.baseDirectory, self.components[1].node);
	self.motorStopSoundOutside = SoundUtil.loadSample(self.xmlFile, {}, "vehicle.motorStopSound", nil, self.baseDirectory, self.components[1].node);

	self.motorStartSoundInside = SoundUtil.loadSample(self.xmlFile, {}, "vehicle.motorStartSoundInside", nil, self.baseDirectory, self.components[1].node);
	self.motorIdleSoundInside = SoundUtil.loadSample(self.xmlFile, {}, "vehicle.motorSoundInside", nil, self.baseDirectory, self.components[1].node);
	self.motorSoundRunInside = SoundUtil.loadSample(self.xmlFile, {}, "vehicle.motorSoundRunInside", nil, self.baseDirectory, self.components[1].node);
	self.motorStopSoundInside = SoundUtil.loadSample(self.xmlFile, {}, "vehicle.motorStopSoundInside", nil, self.baseDirectory, self.components[1].node);
end;

function indoorSound17:delete()
end;

function indoorSound17:mouseEvent(posX, posY, isDown, isUp, button)
end;

function indoorSound17:keyEvent(unicode, sym, modifier, isDown)
end;

function indoorSound17:update(dt)
	if self.isEntered then
		if g_currentMission.driveControl ~= nil and g_currentMission.driveControl.useModules.inDoorSound then
			g_currentMission.driveControl.useModules.inDoorSound = false;
		end;
	end;
	if self:getIsActive() then
		if (self.cameras[self.camIndex].isInside) and (not self.soundSwitched) and (self.isEntered) then
			self:swapSounds("inside");
			self.soundSwitched = true;
		elseif (not self.cameras[self.camIndex].isInside and self.soundSwitched) or (self.isEntered == false and self.soundSwitched) then
			self:swapSounds("outside");
			self.soundSwitched = false;
		end;
	end;
	if self.isHired and not self.isEntered then
		self:swapSounds("outside");
		self.soundSwitched = false;
	end;
end;

function indoorSound17:updateTick(dt)
end;

function indoorSound17:draw()
end;

function indoorSound17:swapSounds(camInOut)
	if SoundUtil.isSamplePlaying(self.sampleMotor) then
		SoundUtil.stopSample(self.sampleMotor, true);
	end;
	if SoundUtil.isSamplePlaying(self.sampleMotorStart) then
		SoundUtil.stopSample(self.sampleMotorStart, true);
	end;
	if SoundUtil.isSamplePlaying(self.sampleMotorStop) then
		SoundUtil.stopSample(self.sampleMotorStop, true);
	end;
	if SoundUtil.isSamplePlaying(self.sampleMotorRun) then
		SoundUtil.stopSample(self.sampleMotorRun, true);
	end;

	if camInOut == "outside" then
		self.sampleMotorStart = self.motorStartSoundOutside;
		self.sampleMotorStop = self.motorStopSoundOutside;
		self.sampleMotor = self.motorIdleSoundOutside;
		self.sampleMotorRun = self.motorSoundRunOutside;
	elseif camInOut == "inside" then
		self.sampleMotorStart = self.motorStartSoundInside;
		self.sampleMotorStop = self.motorStopSoundInside;
		self.sampleMotor = self.motorIdleSoundInside;
		self.sampleMotorRun = self.motorSoundRunInside;
	end;
	if self.isClient and self.isEntered and self.isMotorStarted then
		SoundUtil.playSample(self.sampleMotor, 0,0,nil);
		SoundUtil.playSample(self.sampleMotorRun, 0,0,nil);
	end;
	if self.isClient and not self.isEntered then
		SoundUtil.stopSample(self.motorIdleSoundInside, true);
		SoundUtil.stopSample(self.motorSoundRunInside, true);
	end;
end;